resource "aws_mwaa_environment" "managed_apache_airflow" {
  airflow_configuration_options =  var.airflow_configuration_options

  dag_s3_path                    = var.dags_s3_path
  requirements_s3_path           = var.requirements_s3_path
  requirements_s3_object_version = var.requirements_s3_object_version
  execution_role_arn             = var.aws_mwaa_execution_role_arn
  name                           = var.mwaa_environment_name
  airflow_version                = var.airflow_version

  #Network configuration
  dynamic "network_configuration" {
    for_each = var.network_configuration_enabled ? ["true"] : []
    content {
      security_group_ids = var.security_group_ids
      subnet_ids         = slice(var.subnet_ids, 0, 2)
    }
  }

  #Logging Configuration
  logging_configuration {

    dynamic "dag_processing_logs" {
      for_each = var.dag_processing_logs_enabled ? ["true"] : []
      content {
        enabled   = var.dag_processing_logs_enabled
        log_level = var.dag_processing_log_level
      }
    }

    dynamic "scheduler_logs" {
      for_each = var.scheduler_logs_enabled ? ["true"] : []
      content {
        enabled   = var.scheduler_logs_enabled
        log_level = var.scheduler_log_level
      }
    }

    dynamic "task_logs" {
      for_each = var.task_logs_enabled ? ["true"] : []
      content {
        enabled   = var.task_logs_enabled
        log_level = var.task_log_level
      }
    }

    dynamic "webserver_logs" {
      for_each = var.webserver_logs_enabled ? ["true"] : []
      content {
        enabled   = var.webserver_logs_enabled
        log_level = var.webserver_log_level
      }
    }

    dynamic "worker_logs" {
      for_each = var.worker_logs_enabled ? ["true"] : []
      content {
        enabled   = var.worker_logs_enabled
        log_level = var.worker_log_level
      }
    }
  }

  source_bucket_arn = var.s3_bucket_arn

  tags = var.tags
}
