variable "airflow_configuration_options" {
  type        = map(string)
  description = "parameter specifies airflow override options. Check the Official documentation for all possible configuration options."
  default     = {}
}

variable "dags_s3_path"  {
  type        = string
  description = "The relative path to the DAG folder on your Amazon S3 storage bucket."
  default     = "dags/"
}

variable "requirements_s3_path" {
  type        = string
  description = "The relative path to the requirements.txt file on your Amazon S3 storage bucket. For example, requirements.txt. If a relative path is provided in the request, then requirements_s3_object_version is required"
  default     = ""
}

variable "requirements_s3_object_version" {
  type        = string
  description = "The version of the requirement.txt file we want MWAA to use when it's deployed"
  default     = ""
}

variable "aws_mwaa_execution_role_arn" {
  type        = string
  description = "The Amazon Resource Name (ARN) of the task execution role that the Amazon MWAA and its environment can assume."
  validation {
    condition     = length(var.aws_mwaa_execution_role_arn) > 1
    error_message = "ARN of the task execution role that the Amazon MWAA and its environment can assume must be provided."
  }
}

variable "mwaa_environment_name" {
  type        = string
  description = "Name of the manageed airflow instance name."
  validation {
    condition     = length(var.mwaa_environment_name) > 1
    error_message = "The Name of the manageed airflow instance name must be provided."
  }
}

variable "airflow_version" {
  type        = string
  description = "Airflow version of your environment, will be set by default to the latest version that MWAA supports."
}

###########################
# Networking Configuration
############################

variable "network_configuration_enabled" {
  type    = bool
  description = "The network_configuration block supports the arguments(subnet & security group).More information about the required subnet and security group settings can be found in the official AWS documentation."
  default = true
}

variable "subnet_ids" {
  type        = list(string)
  description = "The private subnet IDs in which the environment should be created. MWAA requires two subnets."

  validation {
    condition = (
      length(var.subnet_ids) > 1
    )
    error_message = "There must be atleast 2 private subnet IDs."
  }
}

variable "security_group_ids" {
  type        = list(string)
  description = "Security groups IDs for the environment. At least one of the security group needs to allow MWAA resources to talk to each other, otherwise MWAA cannot be provisioned."
}

#######################
# Logging Configuration
########################

variable "dag_processing_logs_enabled" {
  type        = bool
  description = "Enabling or disabling the collection of logs"
  default     = true
}

variable "scheduler_logs_enabled" {
  type        = bool
  description = "Enabling or disabling the collection of logs"
  default     = true
}

variable "task_logs_enabled" {
  type        = bool
  description = "Enabling or disabling the collection of logs"
  default     = true
}

variable "webserver_logs_enabled" {
  type        = bool
  description = "Enabling or disabling the collection of logs"
  default     = true
}

variable "worker_logs_enabled" {
  type        = bool
  description = "Enabling or disabling the collection of logs"
  default     = true
}

variable "dag_processing_log_level" {
  type        = string
  description = "Logging level. Valid values: CRITICAL, ERROR, WARNING, INFO, DEBUG. Will be INFO by default."
  default     = "INFO"
}

variable "scheduler_log_level" {
  type        = string
  description = "Logging level. Valid values: CRITICAL, ERROR, WARNING, INFO, DEBUG. Will be INFO by default."
  default     = "INFO"
}

variable "task_log_level" {
  type        = string
  description = "Logging level. Valid values: CRITICAL, ERROR, WARNING, INFO, DEBUG. Will be INFO by default."
  default     = "INFO"
}

variable "webserver_log_level" {
  type        = string
  description = "Logging level. Valid values: CRITICAL, ERROR, WARNING, INFO, DEBUG. Will be INFO by default."
  default     = "INFO"
}

variable "worker_log_level" {
  type        = string
  description = "Logging level. Valid values: CRITICAL, ERROR, WARNING, INFO, DEBUG. Will be INFO by default."
  default     = "INFO"
}

variable "s3_bucket_arn" {
  type        = string
  description = "The Amazon Resource Name (ARN) of your Amazon S3 storage bucket."
}

variable "tags" {
  type        = map(string)
  description = "Standard Tags for managed apache airflow"
  default     = {}
}

